#ifndef MID2250_CONST_H
#define MID2250_CONST_H

#ifdef ISDLLBUILD
    #define MID2250_API extern "C" __declspec(dllexport)
#else
#ifdef __cplusplus
    #define MID2250_API extern "C" __declspec(dllimport)
#else
    #define MID2250_API __declspec(dllimport)
#endif
#endif

#define MAX_OVERLAYS 6

#define MAX_PLAYBACK_STREAMS 20  // maximum number of simultaneous video playbacks
                                 //(actual maximum will be determined by CPU speed)

// error constants 
#define MID2250_SUCCESS             0
#define MID2250_ERR_NONE            0
#define MID2250_ERR_UNSPECIFIED     -1
#define MID2250_ERR_CAPTURING       -2   // already capturing/recording
#define MID2250_ERR_NOTCAPTURING    -3   // not capturing/recording
#define MID2250_ERR_RUNNING         -4   // attempt to set configuration while graph running
#define MID2250_ERR_SNAPSHOT        -5   // currently displaying snapshot
#define MID2250_ERR_INVALIDFILE     -6   // invalid file
#define MID2250_ERR_DIRECTX         -7   // directX error( other specific directX errors are possible)
#define MID2250_ERR_NODEVICE		-8   // device not present
#define MID2250_ERR_NOTINITIALIZED  -9	 // initialization function failed or not called
#define MID2250_ERR_INVALIDMODE    -10  // invalid mode(eg.  record in MJPEG CAPTURE mode)
#define MID2250_ERR_NOMEM          -11  // no memory
#define MID2250_ERR_INVALIDPARAM   -12
#define MID2250_ERR_INVALIDUSERDATA -13  // user data contains MPEG start code 
                                         // user data must not have more than 23 consecutive bits that are zero
                                         // The API user should insert marker codes to avoid this if necessary.
#define MID2250_ERR_NONEWDATA       -14  // no new user data
#define MID2250_ERR_PAUSERESUME_MUX -15

/** sequence modes(advanced use only) */
typedef enum 
{
    MID2250_SEQMODE_IFRAMESONLY,  
    MID2250_SEQMODE_DEFAULT,
    MID2250_SEQMODE_IPFRAMESONLY
} MID2250_SEQMODE;

/** operating modes, Normal, Motion JPEG capture with no rendering(display)
*/
typedef enum
{
    MID2250_OPMODE_NORMAL=0,
    MID2250_OPMODE_MJPEG_CAPTURE,
    MID2250_OPMODE_MPEGONLY_CAPTURE,
    MID2250_OPMODE_SAMPLEGRAB  //future use
} MID2250_OPMODE;

/** video systems.  PAL or NTSC
 */
typedef enum
{
	MID2250_VIDSYS_PAL=1,
	MID2250_VIDSYS_NTSC=2
} MID2250_VIDSYS;


/** Video input source.  Note: Changing input may stop MPEG Video Stream
 * @param MID2250_SOURCE_COMPOSITE_0 Composite channel 0
 * @param MID2250_SOURCE_SVIDEO_0 S-Video Channel 0
 * @param MID2250_SOURCE_NUM maximum number of inputs
 */
typedef enum
{
	MID2250_SOURCE_COMPOSITE_0 = 0,
	MID2250_SOURCE_SVIDEO_0    = 1,
	MID2250_SOURCE_NUM		   = 2    // maximum number of inputs
} MID2250_SOURCE;


/** VIDEO levels */
#define MID2250_LEVEL_CONTRAST		1
#define	MID2250_LEVEL_BRIGHTNESS	    2
#define MID2250_LEVEL_SATURATION	    4
#define MID2250_LEVEL_HUE			8


// image file save bitmask types 
 
#define	MID2250_FILE_JPEG		1
#define	MID2250_FILE_BMP			2
#define	MID2250_FILE_PPM			4


/** Encoding type (MPEG, etc)
 *  Not the default mode for backward compatibility.  MPEG DVD compliant reduces the GOP length to 15
 *  from 30, so compression may be less.
 */
typedef enum
{
	MID2250_ENCODE_MPEG1 = 0,
	MID2250_ENCODE_MPEG2 = 1,
	MID2250_ENCODE_MPEG4 = 2,  // MPEG4
	MID2250_ENCODE_MOTIONJPEG = 3,
    MID2250_ENCODE_MPEG4DIVX = 9, //BETA only
} MID2250_ENCODING;

#ifndef MAX_PATH
#define MAX_PATH 260
#endif


/** General Status information
 * @param bIsRecording true if currently recording
 * @param bIsPlaying true if video playing(for debug)      
 * @param iFilesize current recorded file size and size of all clips
 * @param szFilepath current filepath being recorded
 *         
 */
typedef struct 
{ 
    ULONG       iFilesize;              // current recorded size(megs)
    char        szFilepath[MAX_PATH];   // destination filepath(after stop record)
    BOOL        bIsRecording;           // true if currently recording
    BOOL        bIsPlaying;             // true if video streaming(preview)
} MIDSRAYSTATUS; 

/** General Status information
 * @param bIsRecording true if currently recording
 * @param bIsPlaying true if video playing(for debug)      
 * @param iFilesize current recorded file size and size of all clips
 * @param szFilepath current filepath being recorded
 *         
 */
typedef struct 
{ 
    ULONG       iFilesize;              // current recorded size(megs)
    wchar_t     szFilepath[MAX_PATH];   // destination filepath(after stop record)
    BOOL        bIsRecording;           // true if currently recording
    BOOL        bIsPlaying;             // true if video streaming(preview)
} MIDSRAYSTATUS_UNICODE; 


/** General Status information
 * @param bIsRecording true if currently recording
 * @param bIsPlaying true if video playing(for debug)      
 * @param iFilesize current recorded file size and size of all clips
 * @param szFilepath current filepath being recorded
 * @param szClipFilepath is the where data is being written to currently
 *         
 */
typedef struct 
{ 
    ULONG       iFilesize;              // current recorded size(megs)
    char        szFilepath[MAX_PATH];   // destination filepath(after stop record)
    BOOL        bIsRecording;           // true if currently recording
    BOOL        bIsPlaying;             // true if video streaming(preview)
    char        szReserved[MAX_PATH]; // (was intermediate filepath(MPEG1 and MPEG2))
} MIDSRAYSTATUS_CLIP;  // for SN_GetStatus2 (deprecated)  szReserved will be a copy of szFilePath
					// clip recording not used anymore



/** MID2250_AUDIO_INPUT sets the audio input channel,  
 *  @param MID2250_AUDIO_LINE line in
 *  @param MID2250_AUDIO_MIC microphone
 */
typedef enum
{
	MID2250_AUDIO_LINE,
	MID2250_AUDIO_MIC
}  MID2250_AUDIO_INPUT;


/** aspect ratio settings for MPEG decoding on host computer.  Depending on Decoder, may not have an effect.
 * @param MID2250_ASPECT_NONE no aspect ratio change on MPEG decoding(stretch to window)
 * @param MID2250_ASPECT_CONST maintain aspect ratio as video settings
 */
typedef enum
{	
	MID2250_ASPECT_NONE = 0,	// no aspect ratio change
	MID2250_ASPECT_CONST = 1	// maintain aspect ratio
} MID2250_ASPECT_MODE;

/** recording mode for saved MPEG streams
 *  @param MID2250_REC_MUX multiplexed(video+audio) mpeg stream
 *  @param MID2250_REC_AUDIOWAVE audio only.  recorded as a WAVE file.
 *  @param MID2250_REC_AES encoded audio only (AES mp2 encoding)
 */
/* 6/02/2008.  values changed.
   PES moved to unused valued.  If upgrading from old software without changing your software,
   the SDK will choose the best value for video only streams.
   If you really need PES, it is now a previously unused value.
*/

typedef enum
{
	MID2250_REC_MUX = 0,        // default: multiplexed(video+audio) mpeg stream
	MID2250_REC_VIDEOONLY  = 1,  // recommended video only stream(PES for MPEG1/MPEG2.  AVI for MPEG4)
	MID2250_REC_VIDEOONLY2 = 2,  // (duplicate of above for backwards compat)
	/* Options below are available, but are BETA */
	MID2250_REC_SPLIT1 = 3,     // VES/AES(BETA)
    MID2250_REC_SPLIT2 = 4,     // VES/WAV(BETA)
    MID2250_REC_SPLIT3 = 5,     // PES/AES(not supported for MPEG1 or 2) (BETA)
    MID2250_REC_SPLIT4 = 6,     // PEV/WAV(not supported for MPEG1 or 2) (BETA)
    MID2250_REC_AES = 7,        // Audio elementary stream only(no video, beta)
    MID2250_REC_AUDIOWAVE = 8,  //  audio wave( beta)
	MID2250_REC_PES = 9,        // packetized elementary stream( video only)

} MID2250_REC;


/** motion detection coordinates in pixels*/
typedef struct
{
    int CoordsX;
    int CoordsY;
} MID2250_PointCorrds_t;

/** motion detection regions.  Region 4 is NOT available at this time.  Only 3 regions are available.
 *  eg ULPoint[3], BRPoint[3] values are ignored
 *  @param ULPoint[n] Upper left point coordinate of region n+1.
 *  @param BRPoint[n] bottom right point coordinate of region n+1.
 *  @param u32SADThresholdValues[n] Sum of absolute differences for region n+1. Recommended range 20-150(depends on sensitivity).  
 *  @param u32MVThresholdValues[n] Motion Vector threshold of region n+1. Recommended range 50-1500(depends on sensitivity).
 *  @param u32SensitivityValues[n] Sensitivity. 0-100.  100 will produce too many events in general.  Recommend 0-80 range
 *  To turn off a region, use threshold values of 0x7fff and set ULPoint[n] = {0,0} and BRPoint[n]={0,0}.
 */
typedef struct
{
    MID2250_PointCorrds_t ULPoint[ 4 ];
    MID2250_PointCorrds_t BRPoint[ 4 ];
    unsigned short u32SADThresholdValues[ 4 ];
    unsigned short u32MVThresholdValues[ 4 ];
    unsigned short u32SensitivityValues[ 4 ];
} MID2250_MDConfig_t;


/** Resolution settings( future use only)
 *  D1  -- 720x 480 NTSC, 720x576 PAL
 *  SIF -- 352 x 240  // NTSC only
 *  CIF -- 352 x 288  // PAL only
 *  VGA -- 640x480
 *  4SIF -- 704x480 // NTSC only
 *  4CIF -- 704x576 // PAL only
 *  QCIF -- 176x144 // 
 */
typedef enum
{
	MIDSRAY_RES_D1 = 0,
	MIDSRAY_RES_SIF,  // NTSC only
    MIDSRAY_RES_CIF,  // PAL only
    MIDSRAY_RES_VGA,
    MIDSRAY_RES_QCIF
}  MIDSRAY_RES;



/** overlay text structure
 *  @param text pointer to text
 */
#define MAX_OVLTEXT 96  // maximum TOTAL number of characters in the overlay.
// eg.  User may have one Overlay text with 96 characters
//      or 2 overlays( idx=0, idx=1) with 48 characters each
typedef struct {
	char text[MAX_OVLTEXT];	 // MAX_PATH
    int  fontidx; 
	char reserved[28];
} overlay_text_t;


#endif
